//+------------------------------------------------------------------+
//|                                                Pivot Trading.mq4 |
//|                                   Copyright 2020, Jafarul Warner |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2020, Jafarul Warner"
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict


int leverage = AccountLeverage();



double YH = iHigh(NULL,PERIOD_D1,1); // Yesterday High
double YL = iLow(NULL,PERIOD_D1,1); // Yesterday Low
double YC = iClose(NULL,PERIOD_D1,1); // Yesterday Close
double YPivot = (YH+YL+YC)/3;
double YR1 = (YPivot*2)-YL;
double YS1 = (YPivot*2)-YH;
double YR2 = YPivot+(YR1-YS1);
double YS2 = YPivot-(YR1-YS1);
double lots = AccountBalance() * 0.00005;
double acc = AccountBalance();


//Normalize
double H = NormalizeDouble(YH,5);
double L = NormalizeDouble(YL,5);
double C = NormalizeDouble(YC,5);
double Pivot = NormalizeDouble(YPivot,5);
double R1 = NormalizeDouble(YR1,5);
double S1 = NormalizeDouble(YS1,5);
double R2 = NormalizeDouble(YR2,5);
double S2 = NormalizeDouble(YS2,5);
double balance = NormalizeDouble(acc,5);

string pivotline=DoubleToStr(Pivot, 5);
string Rline1=DoubleToStr(R1, 5);
string Rline2=DoubleToStr(R2, 5);
string Sline1=DoubleToStr(S1, 5);
string Sline2=DoubleToStr(S2, 5);
string Hline=DoubleToStr(H, 5);
string Lline=DoubleToStr(L, 5);
string Cline=DoubleToStr(C, 5);


string  symbol=Symbol();

int  minute=Minute();




//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
double TakeProfitInstant()
  {
      if(Pivot > C)
        {
         return(S1);
        }
   return(R1);
  }
  
double TakeProfitLimit()
  {
      if(Pivot > C)
        {
         return(S2);
        }
   return(R2);
  }
  
double StopLossInstant()
  {
      if(Pivot > C)
        {
         return(H);
        }
   return(L);
  }
  
double StopLossLimit()
  {
      if(Pivot > C)
        {
         return(H);
        }
   return(L);
  }
 



void CloseOrders(){
   
   //Update the exchange rates before closing the orders
   RefreshRates();
      //Log in the terminal the total of orders, current and past
      Print(OrdersTotal());
      
   //Start a loop to scan all the orders
   //The loop starts from the last otherwise it would miss orders
   for(int i=(OrdersTotal()-1);i>=0;i--){
      
      //If the order cannot be selected throw and log an error
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false){
         Print("ERROR - Unable to select the order - ",GetLastError());
         break;
      } 

      //Create the required variables
      //Result variable, to check if the operation is successful or not
      bool res=false;
      
      //Allowed Slippage, which is the difference between current price and close price
      int Slippage=0;
      
      //Bid and Ask Price for the Instrument of the order
      double BidPrice=MarketInfo(OrderSymbol(),MODE_BID);
      double AskPrice=MarketInfo(OrderSymbol(),MODE_ASK);

      //Closing the order using the correct price depending on the type of order
      if(OrderType()==OP_BUY){
         res=OrderClose(OrderTicket(),OrderLots(),BidPrice,Slippage);
      }
      if(OrderType()==OP_SELL){
         res=OrderClose(OrderTicket(),OrderLots(),AskPrice,Slippage);
      }
      
      //If there was an error log it
      if(res==false) Print("ERROR - Unable to close the order - ",OrderTicket()," - ",GetLastError());
   }
}
 
  

//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---
   
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
 {
 
    int Jam=Hour();
    int Min=Minute();
    Comment("Account Balance     = "+(string)balance+"\nLeverage               = 1 : "+(string)leverage+"\nTime                     = "+(string)Jam+" : "+(string)Min);

    //Copyright Line Label
    ObjectCreate("Copyright", OBJ_LABEL, 0, 0, 0);
    ObjectSet("Copyright",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("Copyright",OBJPROP_XDISTANCE, 30);
    ObjectSet("Copyright",OBJPROP_YDISTANCE, 425);
    ObjectSetText("Copyright","Easy Pivot Trading",10, "Verdana", clrGold);
    
    //Copyright Bottom Line Label
    ObjectCreate("CopyrightLine", OBJ_LABEL, 0, 0, 0);
    ObjectSet("CopyrightLine",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("CopyrightLine",OBJPROP_XDISTANCE, 30);
    ObjectSet("CopyrightLine",OBJPROP_YDISTANCE, 440);
    ObjectSetText("CopyrightLine","-------------------------",7, "Verdana", clrGold);
    
    //High Line Label
    ObjectCreate("HValue2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("HValue2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("HValue2",OBJPROP_XDISTANCE, 30);
    ObjectSet("HValue2",OBJPROP_YDISTANCE, 460);
    ObjectSetText("HValue2",Hline,7, "Verdana", clrMagenta);
    
    ObjectCreate("HLine2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("HLine2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("HLine2",OBJPROP_XDISTANCE, 100);
    ObjectSet("HLine2",OBJPROP_YDISTANCE, 460);
    ObjectSetText("HLine2","High Line : ",7, "Verdana", clrCrimson);

    //Low Line Label
    ObjectCreate("LValue2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("LValue2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("LValue2",OBJPROP_XDISTANCE, 30);
    ObjectSet("LValue2",OBJPROP_YDISTANCE, 470);
    ObjectSetText("LValue2",Lline,7, "Verdana", clrMagenta);
    
    ObjectCreate("LLine2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("LLine2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("LLine2",OBJPROP_XDISTANCE, 100);
    ObjectSet("LLine2",OBJPROP_YDISTANCE, 470);
    ObjectSetText("LLine2","Low Line : ",7, "Verdana", clrCrimson);

    //Close Line Label
    ObjectCreate("CValue2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("CValue2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("CValue2",OBJPROP_XDISTANCE, 30);
    ObjectSet("CValue2",OBJPROP_YDISTANCE, 480);
    ObjectSetText("CValue2",Cline,7, "Verdana", clrMagenta);
    
    ObjectCreate("CLine2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("CLine2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("CLine2",OBJPROP_XDISTANCE, 100);
    ObjectSet("CLine2",OBJPROP_YDISTANCE, 480);
    ObjectSetText("CLine2","Close Line : ",7, "Verdana", clrCrimson);

    //Resistance 2 Label
    ObjectCreate("RValue2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("RValue2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("RValue2",OBJPROP_XDISTANCE, 30);
    ObjectSet("RValue2",OBJPROP_YDISTANCE, 500);
    ObjectSetText("RValue2",Rline2,7, "Verdana", clrMagenta);
    
    ObjectCreate("RLine2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("RLine2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("RLine2",OBJPROP_XDISTANCE, 100);
    ObjectSet("RLine2",OBJPROP_YDISTANCE, 500);
    ObjectSetText("RLine2","Resistance Line 2 : ",7, "Verdana", clrCrimson);
    
    //Resistance 1 Label
    ObjectCreate("RValue1", OBJ_LABEL, 0, 0, 0);
    ObjectSet("RValue1",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("RValue1",OBJPROP_XDISTANCE, 30);
    ObjectSet("RValue1",OBJPROP_YDISTANCE, 510);
    ObjectSetText("RValue1",Rline1,7, "Verdana", clrMagenta);
    
    ObjectCreate("RLine1", OBJ_LABEL, 0, 0, 0);
    ObjectSet("RLine1",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("RLine1",OBJPROP_XDISTANCE, 100);
    ObjectSet("RLine1",OBJPROP_YDISTANCE, 510);
    ObjectSetText("RLine1","Resistance Line 1 : ",7, "Verdana", clrCrimson);
    
    //Pivot Label
    ObjectCreate("PivotValue", OBJ_LABEL, 0, 0, 0);
    ObjectSet("PivotValue",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("PivotValue",OBJPROP_XDISTANCE, 30);
    ObjectSet("PivotValue",OBJPROP_YDISTANCE, 520);
    ObjectSetText("PivotValue",pivotline,7, "Verdana", clrMagenta);
    
    ObjectCreate("PivotLine", OBJ_LABEL, 0, 0, 0);
    ObjectSet("PivotLine",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("PivotLine",OBJPROP_XDISTANCE, 100);
    ObjectSet("PivotLine",OBJPROP_YDISTANCE, 520);
    ObjectSetText("PivotLine","Pivot Line : ",7, "Verdana", clrCrimson);
    
    //Support 1 Label
    ObjectCreate("SValue1", OBJ_LABEL, 0, 0, 0);
    ObjectSet("SValue1",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("SValue1",OBJPROP_XDISTANCE, 30);
    ObjectSet("SValue1",OBJPROP_YDISTANCE, 530);
    ObjectSetText("SValue1",Sline1,7, "Verdana", clrMagenta);
    
    ObjectCreate("SLine1", OBJ_LABEL, 0, 0, 0);
    ObjectSet("SLine1",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("SLine1",OBJPROP_XDISTANCE, 100);
    ObjectSet("SLine1",OBJPROP_YDISTANCE, 530);
    ObjectSetText("SLine1","Support Line 1 : ",7, "Verdana", clrCrimson);
    
    //Support 2 Label
    ObjectCreate("SValue2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("SValue2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("SValue2",OBJPROP_XDISTANCE, 30);
    ObjectSet("SValue2",OBJPROP_YDISTANCE, 540);
    ObjectSetText("SValue2",Sline2,7, "Verdana", clrMagenta);
    
    ObjectCreate("SLine2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("SLine2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("SLine2",OBJPROP_XDISTANCE, 100);
    ObjectSet("SLine2",OBJPROP_YDISTANCE, 540);
    ObjectSetText("SLine2","Support Line 2 : ",7, "Verdana", clrCrimson);

    //Copyright End Line Label
    ObjectCreate("Line2", OBJ_LABEL, 0, 0, 0);
    ObjectSet("Line2",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("Line2",OBJPROP_XDISTANCE, 30);
    ObjectSet("Line2",OBJPROP_YDISTANCE, 560);
    ObjectSetText("Line2","-------------------------",7, "Verdana", clrGold);
    
    //Copyright Name Label
    ObjectCreate("Name", OBJ_LABEL, 0, 0, 0);
    ObjectSet("Name",OBJPROP_CORNER, CORNER_RIGHT_UPPER);
    ObjectSet("Name",OBJPROP_XDISTANCE, 62);
    ObjectSet("Name",OBJPROP_YDISTANCE, 570);
    ObjectSetText("Name","\t\x00A9 JafarulFX",7, "Verdana", clrSlateGray);
    
    int CountSymbolPositions=0;
    for(int trade=OrdersTotal()-1;trade>=0;trade++)
    {
      if(!OrderSelect(trade,SELECT_BY_POS,MODE_TRADES))
         continue;
      if(OrderSymbol()==Symbol())
         {
         if((OrderType()==OP_SELL||OrderType()==OP_BUY))
         CountSymbolPositions++;
         }
    }

    
    if (Hour()==01&&Minute()>00)
      {  
                //If Yesterday's Pivot higher than Close = Sell
                if (Pivot>C)
                {
                         // send a sell order
                         int sellticket = OrderSend
                         (
                           Symbol(),         // currency pair on the chart        
                           OP_SELLLIMIT,     // set a SELL LIMIT    
                           lots,             // 10 Microlot            
                           Pivot,            // 200 points above Bid price
                           3,                // 3 Pips slippage                
                           StopLossLimit(),  //Stop Loss		
                           TakeProfitLimit(),// 100 points above Bid price 
                           NULL,             // No comment             
                           0,                // No ID number               
                           0,                // No expiration date                
                           Green             // set arrow color           
                          );  
                          
                          int sellnowticket = OrderSend
                         (
                           Symbol(),         // currency pair on the chart        
                           OP_SELLLIMIT,     // set a SELL LIMIT    
                           lots,             // 10 Microlot            
                           Pivot,            // 200 points above Bid price
                           3,                // 3 Pips slippage                
                           StopLossLimit(),  //Stop Loss		
                           TakeProfitLimit(),// 100 points above Bid price 
                           NULL,             // No comment             
                           0,                // No ID number               
                           0,                // No expiration date                
                           Green             // set arrow color           
                          );
                          
                          
                            
                  }
                     
                  else
                  {
                  
                  // send a sell order
                         int buyticket = OrderSend
                         (
                           Symbol(),         // currency pair on the chart        
                           OP_BUYLIMIT,      // set a SELL LIMIT    
                           lots,             // 10 Microlot            
                           Pivot,            // 200 points above Bid price
                           3,                // 3 Pips slippage                
                           StopLossLimit(),  //Stop Loss		
                           TakeProfitLimit(),// 100 points above Bid price 
                           NULL,             // No comment             
                           0,                // No ID number               
                           0,                // No expiration date                
                           Green             // set arrow color           
                          );
                          
                          int buynowticket = OrderSend
                         (
                           Symbol(),         // currency pair on the chart        
                           OP_BUY,           // set a SELL LIMIT    
                           lots,             // 10 Microlot            
                           Bid,              // 200 points above Bid price
                           3,                // 3 Pips slippage                
                           StopLossLimit(),  //Stop Loss		
                           TakeProfitLimit(),// 100 points above Bid price 
                           NULL,             // No comment             
                           0,                // No ID number               
                           0,                // No expiration date                
                           Green             // set arrow color           
                          );
                          
                          
                  
                  }  

         }
         else
         {
         //if (Hour()>16&&Minute()>05)
         //CloseOrders();
         }
                         
  }

//+------------------------------------------------------------------+
